@@ -4,6 +4,8 @@ import requests
 from google.cloud import pubsub_v1
 from expressmoney.core import Core
 from expressmoney.dataclasses import Status
+from google.cloud import tasks_v2
+import datetime
 
 
 class PubSub:
@@ -128,23 +130,70 @@ class Functions:
 
         user = Core('user')
         profile = Core('profile')
-
         user_obj = user.retrieve(self.initial_event.get('user'))
         profile_obj = profile.retrieve(self.initial_event.get('user'))
+        data = {**user_obj, **profile_obj}
 
-        return self._service_new({**user_obj, **profile_obj})
+        return Status(Status.SUCCESS, 'Demo result comment in _service_new()')
 
     def _in_process(self):
         """Подготовка доменных данных и передача их в сервиса _service_in_process()"""
 
-        return self._service_in_process()
+        raise RuntimeError('Status IN_PROCESS недопустим для Event')
 
-    def _service_in_process(self):
-        """Запускается для событий со статусом IN_PROCESS"""
 
-        raise RuntimeError('Status IN_PROCESS недопустим для Event: {}'.format(str(data)))
+class Tasks:
+    """Работа с Google Cloud Tasks"""
 
-    def _service_new(self, data):
-        """Запускается для событий со статусом NEW"""
+    project = 'expressmoney'
+    location = 'europe-west1'
+    client = tasks_v2.CloudTasksClient()
 
-        return Status(Status.SUCCESS, str('Demo result comment in _service_new()')[255:])
+    def __init__(self, endpoint, in_seconds=None, name=None):
+
+        self.endpoint = endpoint
+
+        self.timestamp = datetime.datetime.utcnow() + datetime.timedelta(seconds=in_seconds)
+
+        self.parent = self.client.queue_path(self.project, self.location, queue=endpoint)
+
+        self.payloads = Core(self.endpoint).list()
+
+        self.task = {
+            'app_engine_http_request': {
+                'http_method': tasks_v2.HttpMethod.PUT,
+                'relative_uri': '',
+                'headers': {
+                    'Content-type': 'application/json',
+                    'Authorization': 'Token {}'.format('')
+                },
+            }
+        }
+
+        if in_seconds is not None:
+            # Convert "seconds from now" into an rfc3339 datetime string.
+            timestamp = datetime.datetime.utcnow() + datetime.timedelta(seconds=in_seconds)
+            # Add the timestamp to the tasks.
+            self.task['schedule_time'] = timestamp
+
+        if name:
+            self.task['name'] = name  # 'my-unique-task'
+
+    def create_tasks(self):
+
+        for payload in self.payloads:
+
+            # Convert dict to JSON string
+            payload_string = json.dumps(payload)
+
+            # The API expects a payload of type bytes.
+            converted_payload = payload_string.encode()
+
+            # Prepares task
+            task = self.task
+            task['app_engine_http_request']['body'] = converted_payload
+            task['app_engine_http_request']['relative_uri'] = '/core/{}/{}/'.format(self.endpoint, payload.get('id'))
+
+            self.client.create_task(parent=self.parent, task=task)
+
+            return Status.SUCCESS, 200
